==> owncloud-9.0.3.tgz: owncloud/settings/l10n/lv.js <==
OC.L10N.register(
    "settings",
    {
    "Sharing" : "Dalīšanās",
    "External Storage" : "Ārējā krātuve",
    "Cron" : "Cron",
    "Log" : "Žurnāls",
    "Updates" : "Atjauninājumi",
    "Couldn't remove app." : "Nebija iespējams atslēgt lietoni.",
    "Language changed" : "Valoda tika nomainīta",
    "Invalid request" : "Nederīgs vaicājums",
    "Authentication error" : "Autentifikācijas kļūda",
    "Admins can't remove themself from the admin group" : "Administratori nevar izņemt paši sevi no administratoru grupas",
    "Unable to add user to group %s" : "Nevar pievienot lietotāju grupai %s",
    "Unable to remove user from group %s" : "Nevar izņemt lietotāju no grupas %s",
    "Couldn't update app." : "Nevarēja atjaunināt lietotni.",
    "Wrong password" : "Nepareiza parole",
    "No user supplied" : "Nav norādīts lietotājs",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Lūdzu ievadiet administratora atjaunošanas paroli, citādi visi lietotāja dati tiks zaudēti",
    "Wrong admin recovery password. Please check the password and try again." : "Nepareiza administratora atjaunošanas parole. Lūdzu pārbaudiet paroli un mēģiniet vēlreiz.",
    "Unable to change password" : "Nav iespējams nomainīt paroli",
    "Enabled" : "Pievienots",
    "Not enabled" : "Nav pievienots",
    "Federated Cloud Sharing" : "Federatīva mākoņkoplietošana",
    "Group already exists." : "Grupa jau eksistē.",
    "Unable to add group." : "Nevar pievienot grupu.",
    "Unable to delete group." : "Nevar izdzēst grupu.",
    "Saved" : "Saglabāts",
    "test email settings" : "testēt e-pasta iestatījumus",
    "Email sent" : "Vēstule nosūtīta",
    "You need to set your user email before being able to send test emails." : "Nepieciešams norādīt sava lietotāja e-pasta adresi, lai nosūtīta testa e-pastus.",
    "Invalid mail address" : "Nepareiza e-pasta adrese",
    "A user with that name already exists." : "Jau pastāv lietotājs ar šo vārdu.",
    "Unable to create user." : "Nevar izveidot lietotāju.",
    "Your %s account was created" : "Konts %s ir izveidots",
    "Unable to delete user." : "Nevar izdzēst lietotāju.",
    "Forbidden" : "Pieeja liegta",
    "Invalid user" : "Nepareizs lietotājs",
    "Unable to change mail address" : "Nevar nomainīt e-pasta adresi",
    "Email saved" : "E-pasts tika saglabāts",
    "Your full name has been changed." : "Jūsu pilnais vārds tika mainīts.",
    "Unable to change full name" : "Nav iespējams nomainīt jūsu pilno vārdu",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Vai esat pārliecināts, ka vēlaties pievienot \"{domain}\" kā uzticamu domēnu?",
    "Add trusted domain" : "Pievienot uzticamu domēnu",
    "Sending..." : "Sūta...",
    "All" : "Visi",
    "No apps found for your version" : "Neatrada aplikāciju jūsu versijai",
    "Please wait...." : "Lūdzu, uzgaidiet....",
    "Error while disabling app" : "Kļūda, atvienojot lietotni",
    "Disable" : "Deaktivēt",
    "Enable" : "Aktivēt",
    "Error while enabling app" : "Kļūda, pievienojot lietotni",
    "Updating...." : "Atjaunina....",
    "Error while updating app" : "Kļūda, atjauninot lietotni",
    "Updated" : "Atjaunināta",
    "Uninstalling ...." : "Atinstalē ....",
    "Error while uninstalling app" : "Kļūda, atinstalējot lietotni",
    "Uninstall" : "Atinstalēt",
    "Valid until {date}" : "Valīds līdz {date}",
    "Delete" : "Dzēst",
    "An error occurred: {message}" : "Notika kļūda: {message}",
    "Select a profile picture" : "Izvēlieties profila attēlu",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Normāla parole",
    "Good password" : "Laba parole",
    "Strong password" : "Lieliska parole",
    "Groups" : "Grupas",
    "Unable to delete {objName}" : "Nevar izdzēst {objName}",
    "A valid group name must be provided" : "Jānorāda derīgs grupas nosaukums",
    "deleted {groupName}" : "grupa {groupName} dzēsta",
    "undo" : "atsaukt",
    "no group" : "neviena grupa",
    "never" : "nekad",
    "deleted {userName}" : "lietotājs {userName} dzēsts",
    "add group" : "pievienot grupu",
    "A valid username must be provided" : "Jānorāda derīgs lietotājvārds",
    "A valid password must be provided" : "Jānorāda derīga parole",
    "A valid email must be provided" : "Jānorāda derīga e-pasta adrese",
    "__language_name__" : "__valodas_nosaukums__",
    "Sync clients" : "Sinhronizācijas lietotnes",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Viss (letālas problēmas, kļūdas, brīdinājumi, informatīvas ziņas, atkļūdošanas paziņojumi)",
    "Info, warnings, errors and fatal issues" : "Informatīvas ziņas, brīdinājumi, kļūdas un letālas problēmas",
    "Warnings, errors and fatal issues" : "Brīdinājumi, kļūdas un letālas problēmas",
    "Errors and fatal issues" : "Kļūdas un letālas problēmas",
    "Fatal issues only" : "Tikai letālas problēmas",
    "None" : "Nav",
    "Login" : "Ierakstīties",
    "Plain" : "vienkāršs teksts",
    "NT LAN Manager" : "NT LAN Pārvaldnieks",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Trūkst PHP modulis “fileinfo”. Mēs iesakām to aktivēt, lai pēc iespējas labāk noteiktu mime tipus.",
    "Open documentation" : "Atvērt dokumentāciju",
    "Allow apps to use the Share API" : "Ļauj lietotnēm izmantot koplietošanas API",
    "Allow users to share via link" : "Ļaut lietotājiem dalīties caur saitēm",
    "Allow public uploads" : "Atļaut publisko augšupielādi",
    "Expire after " : "Nederīga pēc",
    "days" : "dienas",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Execute one task with each page loaded" : "Izpildīt vienu uzdevumu ar katru ielādēto lapu",
    "Enable encryption" : "Ieslēgt šifrēšanu",
    "Encryption" : "Šifrēšana",
    "From address" : "No adreses",
    "Server address" : "Servera adrese",
    "Port" : "Ports",
    "Credentials" : "Akreditācijas dati",
    "SMTP Username" : "SMTP lietotājvārds",
    "SMTP Password" : "SMTP parole",
    "Test email settings" : "Izmēģināt e-pasta iestatījumus",
    "Send email" : "Sūtīt e-pastu",
    "More" : "Vairāk",
    "Less" : "Mazāk",
    "Version" : "Versija",
    "Documentation:" : "Dokumentācija:",
    "User documentation" : "Lietotāja dokumentācija",
    "Admin documentation" : "Administratora dokumentācija",
    "Show description …" : "Rādīt aprakstu …",
    "Hide description …" : "Slēpt aprakstu …",
    "Online documentation" : "Tiešsaistes dokumentācija",
    "Forum" : "Forums",
    "Profile picture" : "Profila attēls",
    "Upload new" : "Ielādēt jaunu",
    "Remove image" : "Novākt attēlu",
    "Cancel" : "Atcelt",
    "Email" : "E-pasts",
    "Your email address" : "Jūsu e-pasta adrese",
    "Password" : "Parole",
    "Unable to change your password" : "Nevar nomainīt jūsu paroli",
    "Current password" : "Pašreizējā parole",
    "New password" : "Jauna parole",
    "Change password" : "Mainīt paroli",
    "Language" : "Valoda",
    "Help translate" : "Palīdzi tulkot",
    "Get the apps to sync your files" : "Saņem lietotnes, lai sinhronizētu savas datnes",
    "Desktop client" : "Darbvirsmas klients",
    "Android app" : "Android lietotne",
    "iOS app" : "iOS lietotne",
    "Show First Run Wizard again" : "Vēlreiz rādīt pirmās palaišanas vedni",
    "Send email to new user" : "Sūtīt e-pastu jaunajam lietotājam",
    "Show email address" : "Rādīt e-pasta adreses",
    "Username" : "Lietotājvārds",
    "E-Mail" : "E-pasts",
    "Create" : "Izveidot",
    "Admin Recovery Password" : "Administratora atgūšanas parole",
    "Enter the recovery password in order to recover the users files during password change" : "Ievadiet atgūšanas paroli, lai varētu atgūt lietotāja failus paroles maiņas laikā.",
    "Add Group" : "Pievienot grupu",
    "Group" : "Grupa",
    "Default Quota" : "Apjoms pēc noklusējuma",
    "Unlimited" : "Neierobežota",
    "Other" : "Cits",
    "Full Name" : "Pilns vārds",
    "Quota" : "Apjoms",
    "set new password" : "iestatīt jaunu paroli",
    "Default" : "Noklusējuma"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> owncloud-10.0.7.tgz: owncloud/settings/l10n/lv.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Nepareiza parole",
    "No user supplied" : "Nav norādīts lietotājs",
    "Authentication error" : "Autentifikācijas kļūda",
    "Wrong admin recovery password. Please check the password and try again." : "Nepareiza administratora atjaunošanas parole. Lūdzu pārbaudiet paroli un mēģiniet vēlreiz.",
    "Unable to change password" : "Nav iespējams nomainīt paroli",
    "Federated Cloud Sharing" : "Federatīva mākoņkoplietošana",
    "Group already exists." : "Grupa jau eksistē.",
    "Unable to add group." : "Nevar pievienot grupu.",
    "Unable to delete group." : "Nevar izdzēst grupu.",
    "Saved" : "Saglabāts",
    "test email settings" : "testēt e-pasta iestatījumus",
    "Email sent" : "Vēstule nosūtīta",
    "You need to set your user email before being able to send test emails." : "Nepieciešams norādīt sava lietotāja e-pasta adresi, lai nosūtīta testa e-pastus.",
    "Invalid mail address" : "Nepareiza e-pasta adrese",
    "A user with that name already exists." : "Jau pastāv lietotājs ar šo vārdu.",
    "Unable to create user." : "Nevar izveidot lietotāju.",
    "Your %s account was created" : "Konts %s ir izveidots",
    "Unable to delete user." : "Nevar izdzēst lietotāju.",
    "Forbidden" : "Pieeja liegta",
    "Invalid user" : "Nepareizs lietotājs",
    "Unable to change mail address" : "Nevar nomainīt e-pasta adresi",
    "Your full name has been changed." : "Jūsu pilnais vārds tika mainīts.",
    "Unable to change full name" : "Nav iespējams nomainīt jūsu pilno vārdu",
    "__language_name__" : "__valodas_nosaukums__",
    "Language changed" : "Valoda tika nomainīta",
    "Invalid request" : "Nederīgs vaicājums",
    "Admins can't remove themself from the admin group" : "Administratori nevar izņemt paši sevi no administratoru grupas",
    "Couldn't remove app." : "Nebija iespējams atslēgt lietoni.",
    "All" : "Visi",
    "Enabled" : "Pievienots",
    "Not enabled" : "Nav pievienots",
    "No apps found for your version" : "Neatrada aplikāciju jūsu versijai",
    "Please wait...." : "Lūdzu, uzgaidiet....",
    "Error while disabling app" : "Kļūda, atvienojot lietotni",
    "Disable" : "Deaktivēt",
    "Enable" : "Aktivēt",
    "Error while enabling app" : "Kļūda, pievienojot lietotni",
    "Updating...." : "Atjaunina....",
    "Error while updating app" : "Kļūda, atjauninot lietotni",
    "Updated" : "Atjaunināta",
    "Uninstalling ...." : "Atinstalē ....",
    "Error while uninstalling app" : "Kļūda, atinstalējot lietotni",
    "Uninstall" : "Atinstalēt",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Vai esat pārliecināts, ka vēlaties pievienot \"{domain}\" kā uzticamu domēnu?",
    "Add trusted domain" : "Pievienot uzticamu domēnu",
    "Valid until {date}" : "Valīds līdz {date}",
    "Delete" : "Dzēst",
    "Sending..." : "Sūta...",
    "An error occurred: {message}" : "Notika kļūda: {message}",
    "Select a profile picture" : "Izvēlieties profila attēlu",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Normāla parole",
    "Good password" : "Laba parole",
    "Strong password" : "Lieliska parole",
    "Groups" : "Grupas",
    "Unable to delete {objName}" : "Nevar izdzēst {objName}",
    "A valid group name must be provided" : "Jānorāda derīgs grupas nosaukums",
    "deleted {groupName}" : "grupa {groupName} dzēsta",
    "undo" : "atsaukt",
    "never" : "nekad",
    "deleted {userName}" : "lietotājs {userName} dzēsts",
    "add group" : "pievienot grupu",
    "no group" : "neviena grupa",
    "A valid username must be provided" : "Jānorāda derīgs lietotājvārds",
    "A valid password must be provided" : "Jānorāda derīga parole",
    "A valid email must be provided" : "Jānorāda derīga e-pasta adrese",
    "User documentation" : "Lietotāja dokumentācija",
    "Online documentation" : "Tiešsaistes dokumentācija",
    "Forum" : "Forums",
    "Documentation:" : "Dokumentācija:",
    "Admin documentation" : "Administratora dokumentācija",
    "Show description …" : "Rādīt aprakstu …",
    "Hide description …" : "Slēpt aprakstu …",
    "Cron" : "Cron",
    "Open documentation" : "Atvērt dokumentāciju",
    "Execute one task with each page loaded" : "Izpildīt vienu uzdevumu ar katru ielādēto lapu",
    "Enable encryption" : "Ieslēgt šifrēšanu",
    "Sharing" : "Dalīšanās",
    "Allow apps to use the Share API" : "Ļauj lietotnēm izmantot koplietošanas API",
    "Allow users to share via link" : "Ļaut lietotājiem dalīties caur saitēm",
    "Allow public uploads" : "Atļaut publisko augšupielādi",
    "Expire after " : "Nederīga pēc",
    "days" : "dienas",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Viss (letālas problēmas, kļūdas, brīdinājumi, informatīvas ziņas, atkļūdošanas paziņojumi)",
    "Info, warnings, errors and fatal issues" : "Informatīvas ziņas, brīdinājumi, kļūdas un letālas problēmas",
    "Warnings, errors and fatal issues" : "Brīdinājumi, kļūdas un letālas problēmas",
    "Errors and fatal issues" : "Kļūdas un letālas problēmas",
    "Fatal issues only" : "Tikai letālas problēmas",
    "Log" : "Žurnāls",
    "None" : "Nav",
    "Login" : "Ierakstīties",
    "Plain" : "vienkāršs teksts",
    "NT LAN Manager" : "NT LAN Pārvaldnieks",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Encryption" : "Šifrēšana",
    "From address" : "No adreses",
    "Server address" : "Servera adrese",
    "Port" : "Ports",
    "Credentials" : "Akreditācijas dati",
    "SMTP Username" : "SMTP lietotājvārds",
    "SMTP Password" : "SMTP parole",
    "Test email settings" : "Izmēģināt e-pasta iestatījumus",
    "Send email" : "Sūtīt e-pastu",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Trūkst PHP modulis “fileinfo”. Mēs iesakām to aktivēt, lai pēc iespējas labāk noteiktu mime tipus.",
    "Get the apps to sync your files" : "Saņem lietotnes, lai sinhronizētu savas datnes",
    "Desktop client" : "Darbvirsmas klients",
    "Android app" : "Android lietotne",
    "iOS app" : "iOS lietotne",
    "Show First Run Wizard again" : "Vēlreiz rādīt pirmās palaišanas vedni",
    "Profile picture" : "Profila attēls",
    "Upload new" : "Ielādēt jaunu",
    "Remove image" : "Novākt attēlu",
    "Cancel" : "Atcelt",
    "Full name" : "Pilns vārds",
    "Email" : "E-pasts",
    "Your email address" : "Jūsu e-pasta adrese",
    "You are member of the following groups:" : "Jūs esat šādu grupu biedrs:",
    "Password" : "Parole",
    "Unable to change your password" : "Nevar nomainīt jūsu paroli",
    "Current password" : "Pašreizējā parole",
    "New password" : "Jauna parole",
    "Change password" : "Mainīt paroli",
    "Language" : "Valoda",
    "Help translate" : "Palīdzi tulkot",
    "Unlimited" : "Neierobežota",
    "Name" : "Nosaukums",
    "Username" : "Lietotājvārds",
    "Done" : "Pabeigts",
    "Version" : "Versija",
    "Personal" : "Personīgi",
    "Admin" : "Administratori",
    "Error" : "Kļūda",
    "Send email to new user" : "Sūtīt e-pastu jaunajam lietotājam",
    "Show email address" : "Rādīt e-pasta adreses",
    "E-Mail" : "E-pasts",
    "Create" : "Izveidot",
    "Admin Recovery Password" : "Administratora atgūšanas parole",
    "Enter the recovery password in order to recover the users files during password change" : "Ievadiet atgūšanas paroli, lai varētu atgūt lietotāja failus paroles maiņas laikā.",
    "Add Group" : "Pievienot grupu",
    "Group" : "Grupa",
    "Default Quota" : "Apjoms pēc noklusējuma",
    "Other" : "Cits",
    "Full Name" : "Pilns vārds",
    "Quota" : "Apjoms",
    "set new password" : "iestatīt jaunu paroli",
    "Default" : "Noklusējuma"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
